<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://snufel.com/team
 * @since             1.0.0
 * @package           Snufel_Free_Guest
 *
 * @wordpress-plugin
 * Plugin Name:       Snufel Free Guest Post
 * Plugin URI:        https://snufel.com
 * Description:       Start accepting guest posts from companies or small businesses and gain recognition. Set the minimum number of words that guest have to write to get approved.
 * Version:           1.0.0
 * Author:            Snufel
 * Author URI:        https://snufel.com/team
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       snufel-free-guest
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'SNUFEL_FREE_GUEST_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-snufel-free-guest-activator.php
 */
function activate_snufel_free_guest() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-snufel-free-guest-activator.php';
	Snufel_Free_Guest_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-snufel-free-guest-deactivator.php
 */
function deactivate_snufel_free_guest() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-snufel-free-guest-deactivator.php';
	Snufel_Free_Guest_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_snufel_free_guest' );
register_deactivation_hook( __FILE__, 'deactivate_snufel_free_guest' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-snufel-free-guest.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_snufel_free_guest() {

	$plugin = new Snufel_Free_Guest();
	$plugin->run();

}
run_snufel_free_guest();
